==> aTunes_1.9.0.tar.gz: aTunes/src/net/sourceforge/atunes/kernel/executors/processes/ChangeTitlesProcess.java <==
/*
 * aTunes 1.9.0
 * Copyright (C) 2006-2008 Alex Aranda, Sylvain Gaudard, Thomas Beckers and contributors
 *
 * See http://www.atunes.org/wiki/index.php?title=Contributing for information about contributors
 *
 * http://www.atunes.org
 * http://sourceforge.net/projects/atunes
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 */

package net.sourceforge.atunes.kernel.executors.processes;

import java.util.ArrayList;
import java.util.List;
import java.util.Map;

import javax.swing.SwingUtilities;

import net.sourceforge.atunes.kernel.handlers.AudioScrobblerServiceHandler;
import net.sourceforge.atunes.kernel.handlers.VisualHandler;
import net.sourceforge.atunes.kernel.modules.repository.audio.AudioFile;
import net.sourceforge.atunes.kernel.modules.repository.tags.writer.TagModifier;
import net.sourceforge.atunes.utils.LanguageTool;
import net.sourceforge.atunes.utils.StringUtils;
import net.sourceforge.atunes.utils.log4j.LogCategories;
import net.sourceforge.atunes.utils.log4j.Logger;

/**
 * The Class ChangeTitlesProcess.
 */
public class ChangeTitlesProcess implements Runnable {

	/** The logger. */
	private Logger logger = new Logger();

	/** The files. */
	private List<AudioFile> files;

	/** The files and titles. */
	private Map<AudioFile, String> filesAndTitles;

	/**
	 * Instantiates a new change titles process.
	 * 
	 * @param files
	 *            the files
	 */
	public ChangeTitlesProcess(List<AudioFile> files) {
		super();
		this.files = files;
	}

	/**
	 * Instantiates a new change titles process.
	 * 
	 * @param filesAndTitles
	 *            the files and titles
	 */
	public ChangeTitlesProcess(Map<AudioFile, String> filesAndTitles) {
		super();
		this.filesAndTitles = filesAndTitles;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see java.lang.Runnable#run()
	 */
	@Override
	public void run() {
		logger.debug(LogCategories.PROCESS);
		VisualHandler.getInstance().showIndeterminateProgressDialog(StringUtils.getString(LanguageTool.getString("PERFORMING_CHANGES"), "..."));
		if (filesAndTitles == null) {
			filesAndTitles = AudioScrobblerServiceHandler.getInstance().getTitlesForFiles(files);
		}
		if (!filesAndTitles.isEmpty()) {
			final List<AudioFile> filesToEdit = new ArrayList<AudioFile>();
			for (AudioFile file : filesAndTitles.keySet()) {
				String newTitle = filesAndTitles.get(file);
				TagModifier.setTitles(file, newTitle);
				filesToEdit.add(file);
			}
			SwingUtilities.invokeLater(new Runnable() {
				@Override
				public void run() {
					TagModifier.refreshAfterTagModify(filesToEdit);
				}
			});
		}
		VisualHandler.getInstance().hideIndeterminateProgressDialog();
	}
}

==> aTunes_1.10.1.tar.gz: aTunes/src/net/sourceforge/atunes/kernel/executors/processes/ChangeTitlesProcess.java <==
/*
 * aTunes 1.10.1
 * Copyright (C) 2006-2008 Alex Aranda, Sylvain Gaudard, Thomas Beckers and contributors
 *
 * See http://www.atunes.org/wiki/index.php?title=Contributing for information about contributors
 *
 * http://www.atunes.org
 * http://sourceforge.net/projects/atunes
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 */

package net.sourceforge.atunes.kernel.executors.processes;

import java.util.ArrayList;
import java.util.List;
import java.util.Map;

import javax.swing.SwingUtilities;

import net.sourceforge.atunes.kernel.handlers.ContextInformationServiceHandler;
import net.sourceforge.atunes.kernel.handlers.VisualHandler;
import net.sourceforge.atunes.kernel.modules.repository.audio.AudioFile;
import net.sourceforge.atunes.kernel.modules.repository.tags.writer.TagModifier;
import net.sourceforge.atunes.utils.LanguageTool;
import net.sourceforge.atunes.utils.StringUtils;
import net.sourceforge.atunes.utils.log4j.LogCategories;
import net.sourceforge.atunes.utils.log4j.Logger;

/**
 * The Class ChangeTitlesProcess.
 */
public class ChangeTitlesProcess implements Runnable {

	/** The logger. */
	private Logger logger = new Logger();

	/** The files. */
	private List<AudioFile> files;

	/** The files and titles. */
	private Map<AudioFile, String> filesAndTitles;

	/**
	 * Instantiates a new change titles process.
	 * 
	 * @param files
	 *            the files
	 */
	public ChangeTitlesProcess(List<AudioFile> files) {
		super();
		this.files = files;
	}

	/**
	 * Instantiates a new change titles process.
	 * 
	 * @param filesAndTitles
	 *            the files and titles
	 */
	public ChangeTitlesProcess(Map<AudioFile, String> filesAndTitles) {
		super();
		this.filesAndTitles = filesAndTitles;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see java.lang.Runnable#run()
	 */
	@Override
	public void run() {
		logger.debug(LogCategories.PROCESS);
		VisualHandler.getInstance().showIndeterminateProgressDialog(StringUtils.getString(LanguageTool.getString("PERFORMING_CHANGES"), "..."));
		if (filesAndTitles == null) {
			filesAndTitles = ContextInformationServiceHandler.getInstance().getTitlesForFiles(files);
		}
		if (!filesAndTitles.isEmpty()) {
			final List<AudioFile> filesToEdit = new ArrayList<AudioFile>();
			for (AudioFile file : filesAndTitles.keySet()) {
				String newTitle = filesAndTitles.get(file);
				TagModifier.setTitles(file, newTitle);
				filesToEdit.add(file);
			}
			SwingUtilities.invokeLater(new Runnable() {
				@Override
				public void run() {
					TagModifier.refreshAfterTagModify(filesToEdit);
				}
			});
		}
		VisualHandler.getInstance().hideIndeterminateProgressDialog();
	}
}
